@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1305';
+our $VERSION = '0.1306';
 
 use Moo;
 use Music::Chord::Note;
@@ -181,6 +181,11 @@ sub _invert_chord {
                 s/-1//;
                 s/0//;
             }
+
+            if ( $self->format eq 'midi' ) {
+                s/#/s/;
+                s/b/f/;
+            }
         }
     }
 
@@ -255,7 +260,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1305
+version 0.1306
 
 =head1 SYNOPSIS
 
